==> kmyfirewall-trinity-3.5.13.2.tar.xz: kmyfirewall-trinity-3.5.13.2/KMFSysTray/kmfsystray.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Hubinger   *
 *   e9806056@student.tuwien.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/


#ifndef KMFSYSTRAY_H
#define KMFSYSTRAY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// QT includes
#include <tqstring.h>
#include <tqpixmap.h>

// KDE Includes
#include <kpanelapplet.h>
#include <ksystemtray.h>
#include <kconfig.h>
#include <dcopobject.h>

class KAboutData;
class KMFIPTDoc;

class KMFSysTray : public KSystemTray, public DCOPObject
{
    Q_OBJECT
  TQ_OBJECT

public:
    KMFSysTray( TQWidget * );
    virtual ~KMFSysTray();
    virtual int widthForHeight(int height) const;
    virtual int heightForWidth(int width) const;
    virtual void about();
    virtual void help();
    virtual void preferences();
 
public slots:
	void slotSetRunningStatus( bool on );
	void slotLaunchKMF();
	void slotShowDetails();
	void slotQueryDetails();
	void slotDetailsClosed();

protected:
     void resizeEvent(TQResizeEvent *);

private: // Methods
	void initMenu();

private:
	KAboutData *_aboutData;
    KConfig *ksConfig;
    TQWidget *mainView;
	TQPixmap baseIcon;

signals:
	void sigUpdateIPTDoc( KMFIPTDoc* );
	void sigQueryDetails( bool );
	void sigUpdateRuleCount( const TQString&, const TQString&, int );
};

#endif

==> kmyfirewall-trinity-14.1.0.tar.xz: kmyfirewall-trinity-14.1.0/KMFSysTray/kmfsystray.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Christian Hubinger   *
 *   e9806056@student.tuwien.ac.at   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/


#ifndef KMFSYSTRAY_H
#define KMFSYSTRAY_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// QT includes
#include <tqstring.h>
#include <tqpixmap.h>

// KDE Includes
#include <kpanelapplet.h>
#include <ksystemtray.h>
#include <tdeconfig.h>
#include <dcopobject.h>

class TDEAboutData;
class KMFIPTDoc;

class KMFSysTray : public KSystemTray, public DCOPObject
{
    Q_OBJECT
  

public:
    KMFSysTray( TQWidget * );
    virtual ~KMFSysTray();
    virtual int widthForHeight(int height) const;
    virtual int heightForWidth(int width) const;
    virtual void about();
    virtual void help();
    virtual void preferences();
 
public slots:
	void slotSetRunningStatus( bool on );
	void slotLaunchKMF();
	void slotShowDetails();
	void slotQueryDetails();
	void slotDetailsClosed();

protected:
     void resizeEvent(TQResizeEvent *);

private: // Methods
	void initMenu();

private:
	TDEAboutData *_aboutData;
    TDEConfig *ksConfig;
    TQWidget *mainView;
	TQPixmap baseIcon;

signals:
	void sigUpdateIPTDoc( KMFIPTDoc* );
	void sigQueryDetails( bool );
	void sigUpdateRuleCount( const TQString&, const TQString&, int );
};

#endif
